@@ -1086,10 +1086,9 @@ _search_and_insert_contact_attribute(ScoutWindow* self, OssoABookContact* contac
     const gchar* value = NULL;
     gchar* prefix = NULL;
     gchar* suffix = NULL;
-    if(values)
+    while(values)
     {
       value = (const gchar*) values->data;
-    }
     if(value && 
        _find_in_text(self, value, &prefix, &suffix))
     {
@@ -1121,6 +1120,8 @@ _search_and_insert_contact_attribute(ScoutWindow* self, OssoABookContact* contac
       g_free(suffix);
       return true;
     }
+    values = values->next;
+    }
   }
   g_list_free(attributes);
   return false;
@@ -1172,6 +1173,10 @@ search_in_contacts(ScoutWindow* self)
     {
       continue;
     }
+    if(_search_and_insert_contact_attribute(self, original_contact, EVC_ADR))
+    {
+      continue;
+    }
     const GList *fields = (const GList*)osso_abook_account_manager_get_primary_vcard_fields(self->priv->acc_manager);
     for (;fields; fields = fields->next) 
     {
@@ -1776,7 +1781,6 @@ _enable_start_search(ScoutWindow* self)
 {
   if(!self->priv->search_active)
   {
-    g_warning("enable search\n");
     g_free(self->priv->current_search_text);
     self->priv->current_search_text = NULL;
   }
